@@ -11,6 +11,7 @@ import functools
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMin
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRank
 from PyFin.Analysis.TechnicalAnalysis import SecurityMaximumValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMinimumValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingQuantile
@@ -22,7 +23,6 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityMovingStandardDeviation
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCountedPositive
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingPositiveAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRSI
-from PyFin.Analysis.TechnicalAnalysis import SecurityMovingHistoricalWindow
 from PyFin.Analysis.TechnicalAnalysis import SecuritySignValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityXAverageValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMACDValueHolder
@@ -38,9 +38,6 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityAcosValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAcoshValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinhValueHolder
-from PyFin.Analysis.TechnicalAnalysis import SecurityMovingResidue
-from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCorrelation
-from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRank
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
@@ -54,8 +51,8 @@ from PyFin.Analysis.CrossSectionValueHolders import CSQuantileSecurityValueHolde
 from PyFin.Analysis.CrossSectionValueHolders import CSResidueSecurityValueHolder
 
 
-def CSRank(dependency):
-    return CSRankedSecurityValueHolder(dependency)
+def CSRank(dependency, groups=None):
+    return CSRankedSecurityValueHolder(dependency, groups)
 
 
 def CSMean(dependency):
@@ -98,18 +95,6 @@ def RSI(window, dependency='x'):
     return SecurityMovingRSI(window, dependency)
 
 
-def RES(window, dependency=('y', 'x')):
-    return SecurityMovingResidue(window, dependency)
-
-
-def CORR(window, dependency=('x', 'y')):
-    return SecurityMovingCorrelation(window, dependency)
-
-
-def RANK(window, dependency='x'):
-    return SecurityMovingRank(window, dependency)
-
-
 def MA(window, dependency='x'):
     return SecurityMovingAverage(window, dependency)
 
@@ -122,6 +107,10 @@ def MMIN(window, dependency='x'):
     return SecurityMovingMin(window, dependency)
 
 
+def MRANK(window, dependency='x'):
+    return SecurityMovingRank(window, dependency)
+
+
 def MAXIMUM(dependency=('x', 'y')):
     return SecurityMaximumValueHolder(dependency)
 
@@ -162,10 +151,6 @@ def MAPOSITIVE(window, dependency='x'):
     return SecurityMovingPositiveAverage(window, dependency)
 
 
-def HIST(window, dependency='x'):
-    return SecurityMovingHistoricalWindow(window, dependency)
-
-
 def LAST(dependency='x'):
     return SecurityLatestValueHolder(dependency)
 
