@@ -26,6 +26,7 @@ from PyFin.api.Analysis import RSI
 from PyFin.api.Analysis import MA
 from PyFin.api.Analysis import MMAX
 from PyFin.api.Analysis import MMIN
+from PyFin.api.Analysis import MRANK
 from PyFin.api.Analysis import MAXIMUM
 from PyFin.api.Analysis import MINIMUM
 from PyFin.api.Analysis import MQUANTILE
@@ -36,7 +37,6 @@ from PyFin.api.Analysis import MVARIANCE
 from PyFin.api.Analysis import MSTD
 from PyFin.api.Analysis import MNPOSITIVE
 from PyFin.api.Analysis import MAPOSITIVE
-from PyFin.api.Analysis import HIST
 from PyFin.api.Analysis import LAST
 from PyFin.api.Analysis import HIGH
 from PyFin.api.Analysis import LOW
@@ -56,9 +56,6 @@ from PyFin.api.Analysis import ASIN
 from PyFin.api.Analysis import ASINH
 from PyFin.api.Analysis import SHIFT
 from PyFin.api.Analysis import IIF
-from PyFin.api.Analysis import RES
-from PyFin.api.Analysis import CORR
-from PyFin.api.Analysis import RANK
 
 from PyFin.api.Analysis import CSRank
 from PyFin.api.Analysis import CSMean
@@ -91,6 +88,7 @@ __all__ = ["datesList",
            "MA",
            "MMAX",
            "MMIN",
+           "MRANK",
            "MAXIMUM",
            "MINIMUM",
            "MQUANTILE",
@@ -101,7 +99,6 @@ __all__ = ["datesList",
            "MSTD",
            "MNPOSITIVE",
            "MAPOSITIVE",
-           "HIST",
            "LAST",
            "HIGH",
            "LOW",
@@ -119,9 +116,6 @@ __all__ = ["datesList",
            "ACOSH",
            "ASIN",
            "ASINH",
-           "RES",
-           "CORR",
-           "RANK",
            "SHIFT",
            "IIF",
            "CSRank",
