@@ -23,14 +23,16 @@ class TestCrossSectionValueHolder(unittest.TestCase):
 
     def setUp(self):
         np.random.seed(0)
-        sample1 = np.random.randn(1000, 2)
-        sample2 = np.random.randn(1000, 2)
+        sample1 = np.random.randn(1000, 4)
+        sample2 = np.random.randn(1000, 4)
 
         self.datas = {'aapl': {'close': sample1[:, 0], 'open': sample1[:, 1]},
-                      'ibm': {'close': sample2[:, 0], 'open': sample2[:, 1]}}
+                      'ibm': {'close': sample2[:, 0], 'open': sample2[:, 1]},
+                      'goog': {'close': sample1[:, 2], 'open': sample1[:, 3]},
+                      'baba': {'close': sample2[:, 2], 'open': sample2[:, 3]}}
 
     def testCSRankedSecurityValueHolderWithSymbolName(self):
-        benchmark = SecurityLatestValueHolder(dependency='close')
+        benchmark = SecurityLatestValueHolder(x='close')
         rankHolder = CSRankedSecurityValueHolder('close')
 
         for i in range(len(self.datas['aapl']['close'])):
@@ -44,7 +46,7 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             np.testing.assert_array_almost_equal(benchmarkValues.rank().values, rankHolder.value.values)
 
     def testCSRankedSecurityValueHolder(self):
-        benchmark = SecurityLatestValueHolder(dependency='close')
+        benchmark = SecurityLatestValueHolder(x='close')
         rankHolder = CSRankedSecurityValueHolder(benchmark)
 
         for i in range(len(self.datas['aapl']['close'])):
@@ -57,8 +59,33 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             benchmarkValues = benchmark.value
             np.testing.assert_array_almost_equal(benchmarkValues.rank().values, rankHolder.value.values)
 
+    def testCSRankedSecurityValueHolderWithGroups(self):
+        benchmark = SecurityLatestValueHolder(x='close')
+        groups = SecurityLatestValueHolder(x='ind')
+        rankHolder = CSRankedSecurityValueHolder(benchmark, groups)
+
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i],
+                             'ind': 1.},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i],
+                            'ind': 1.},
+                    'goog': {Factors.CLOSE: self.datas['goog'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['goog'][Factors.OPEN][i],
+                             'ind': 2.},
+                    'baba': {Factors.CLOSE: self.datas['baba'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['baba'][Factors.OPEN][i],
+                             'ind': 2.}}
+            benchmark.push(data)
+            rankHolder.push(data)
+            benchmarkValues = benchmark.value
+            groups = {'aapl': 1., 'ibm': 1., 'goog': 2., 'baba': 2.}
+            expected_rank = pd.Series(benchmarkValues.to_dict()).groupby(groups).rank().values - 1.
+            np.testing.assert_array_almost_equal(expected_rank, rankHolder.value.values)
+
     def testCSAverageSecurityValueHolder(self):
-        benchmark = SecurityLatestValueHolder(dependency='close')
+        benchmark = SecurityLatestValueHolder(x='close')
         meanHolder = CSAverageSecurityValueHolder(benchmark)
 
         for i in range(len(self.datas['aapl']['close'])):
@@ -73,7 +100,7 @@ class TestCrossSectionValueHolder(unittest.TestCase):
 
     def testCSPercentileSecurityValueHolder(self):
         percent = 50
-        benchmark = SecurityLatestValueHolder(dependency='close')
+        benchmark = SecurityLatestValueHolder(x='close')
         perHolder = CSPercentileSecurityValueHolder(percent, benchmark)
 
         for i in range(len(self.datas['aapl']['close'])):
@@ -87,7 +114,7 @@ class TestCrossSectionValueHolder(unittest.TestCase):
             np.testing.assert_array_almost_equal(np.percentile(benchmarkValues.values, 50), perHolder.value.values)
 
     def testCSAverageAdjustedSecurityValueHolder(self):
-        benchmark = SecurityLatestValueHolder(dependency='close')
+        benchmark = SecurityLatestValueHolder(x='close')
         meanAdjustedHolder = CSAverageAdjustedSecurityValueHolder(benchmark)
 
         for i in range(len(self.datas['aapl']['close'])):
@@ -117,7 +144,7 @@ class TestCrossSectionValueHolder(unittest.TestCase):
 
         data = np.linspace(1., 0., 10)
 
-        expected = pd.Series(data=data, index=[x for x in range(1, 11)])
+        expected = pd.Series(data=data, index=[x for x in range(0, 10)])
 
         np.testing.assert_array_almost_equal(expected.values, calculated.values)
 
@@ -142,8 +169,8 @@ class TestCrossSectionValueHolder(unittest.TestCase):
         np.testing.assert_array_almost_equal(expected, calculated.values)
 
     def testCSZResidueSecurityValueHolder(self):
-        y = SecurityLatestValueHolder(dependency='close')
-        x = SecurityLatestValueHolder(dependency='open')
+        y = SecurityLatestValueHolder(x='close')
+        x = SecurityLatestValueHolder(x='open')
 
         res = CSResidueSecurityValueHolder(y, x)
 
